ATel #12501: Asiago spectroscopic classification of two transients.

Outside GCN IAUCs Other ATel on Twitter and Facebook ATELstream ATel Community Site | Post | Search | Policies Credential | Feeds | Email 4 May 2020; 09:21 UT | This space for free for your conference.

[ Previous | Next | ADS ] # Asiago spectroscopic classification of two transients. ATel #12501; L. Tomasella, S. Benetti, E. Cappellaro, M. Turatto (INAF Osservatorio Astronomico di Padova) on 13 Feb 2019; 11:53 UT Distributed as an Instant Email Notice Supernovae Credential Certification: Stefano Benetti (stefano.benetti@oapd.inaf.it) Subjects: Optical, Supernovae Tweet The Asiago Transient Classification Program (Tomasella et al. 2014, AN, 335, 841) reports the spectroscopic observation of AT2019ava and AT2019avi. The targets were supplied by ZTF (see Kulkarni et al. 2018, ATel #11266) and ATLAS (see Tonry et al. 2011, PASP, 123, 58, and Tonry et al. ATel #8680) surveys. The observations were performed with the Asiago 1.82m Copernico Telescope (+AFOSC; range 340-820 nm; resolution 1.4 nm).
    Survey name  | IAU name  | Host galaxy            | Disc. Date (UT)     | Obs. Date (UT)      | redshift   | type | phase      | notes
    ZTF19aahulyd | SN2019ava | KUG 0728+583           | 2019-02-12 13:15:26 | 2019-02-13 00:48:46 | 0.039807   | Ia   | before max | (1)
    ZTF19aailexm | SN2019avi | 2MASX J10013204+3915367| 2019-01-08 10:43:05 | 2019-02-12 22:46:24 | 0.06303428 | Ia   | before max | (2)
(1) Spectrum similar to those of several type Ia SNe, few days before maximum light. Redshift of the host galaxy KUG 0728+583 is from Rines et al. 2000 (AJ 120, 2338, via NED). Using this redshift, an expansion velocity of about 12900 km/s is derived from the SiII 635.5 nm minimum. (2) Spectrum similar to several type Ia SNe, about one week before B maximum. The redshift is derived from the lines of the host galaxy. The classification was performed using the GELATO (Harutyunyan et al. 2008, A&A, 488, 383) and SNID (Blondin and Tonry 2007, ApJ, 666, 1024) tools. The Asiago classification spectra are posted at the website http://sngroup.oapd.inaf.it. |